@@ -6,6 +6,7 @@
 #' @param background a background vector containing gene symbols as the test background. If NULL, by default all annotatable are used as background
 #' @param check.symbol.identity logical to indicate whether to match the input data/background via Synonyms for those unmatchable by official gene symbols. By default, it sets to false
 #' @param ontology the ontology supported currently. By default, it is 'NA' to disable this option. Pre-built ontology and annotation data are detailed in \code{\link{xDefineOntology}}.
+#' @param ontology.customised an object 'GS'. Higher priority over 'ontology' above. Required, otherwise it will return NULL
 #' @param size.range the minimum and maximum size of members of each term in consideration. By default, it sets to a minimum of 10 but no more than 2000
 #' @param min.overlap the minimum number of overlaps. Only those terms with members that overlap with input data at least min.overlap (3 by default) will be processed
 #' @param which.distance which terms with the distance away from the ontology root (if any) is used to restrict terms in consideration. By default, it sets to 'NULL' to consider all distances
@@ -58,18 +59,18 @@
 #' RData.location <- "http://galahad.well.ox.ac.uk/bigdata/"
 #' 
 #' # Gene-based enrichment analysis using REACTOME pathways
-#' # a) provide the input Genes of interest (eg 100 randomly chosen human genes)
+#' # a) provide the input Genes of interest (eg 500 randomly chosen human genes)
 #' ## load human genes
 #' org.Hs.eg <- xRDataLoader(RData='org.Hs.eg', RData.location=RData.location)
 #' set.seed(825)
-#' data <- as.character(sample(org.Hs.eg$gene_info$Symbol, 100))
+#' data <- as.character(sample(org.Hs.eg$gene_info$Symbol, 500))
 #' data
 #' 
 #' # optionally, provide the test background (if not provided, all human genes)
 #' #background <- as.character(org.Hs.eg$gene_info$Symbol)
 #' 
 #' # b) perform enrichment analysis
-#' eTerm <- xEnricherGenes(data=data, ontology="REACTOME", RData.location=RData.location)
+#' eTerm <- xEnricherGenes(data=data, ontology="MsigdbC2REACTOME", RData.location=RData.location)
 #'
 #' # c) view enrichment results for the top significant terms
 #' xEnrichViewer(eTerm)
@@ -80,8 +81,8 @@
 #' utils::write.table(output, file="REACTOME_enrichments.txt", sep="\t", row.names=FALSE)
 #'
 #' # e) barplot of significant enrichment results
-#' bp <- xEnrichBarplot(eTerm, top_num="auto", displayBy="adjp")
-#' print(bp)
+#' gp <- xEnrichBarplot(eTerm, top_num="auto", displayBy="adjp")
+#' print(gp)
 #'
 #' # f) visualise the top 10 significant terms in the ontology hierarchy
 #' # color-code terms according to the adjust p-values (taking the form of 10-based negative logarithm)
@@ -98,7 +99,7 @@
 #' xEnrichDAGplot(eTerm, top_num="auto", ig=ig, displayBy="adjp", node.info=c("full_term_name"), graph.node.attrs=list(fontsize=25))
 #' }
 
-xEnricherGenes <- function(data, background=NULL, check.symbol.identity=F, ontology=NA, size.range=c(10,2000), min.overlap=3, which.distance=NULL, test=c("hypergeo","fisher","binomial"), background.annotatable.only=NULL, p.tail=c("one-tail","two-tails"), p.adjust.method=c("BH", "BY", "bonferroni", "holm", "hochberg", "hommel"), ontology.algorithm=c("none","pc","elim","lea"), elim.pvalue=1e-2, lea.depth=2, path.mode=c("all_paths","shortest_paths","all_shortest_paths"), true.path.rule=F, verbose=T, silent=FALSE, RData.location="http://galahad.well.ox.ac.uk/bigdata")
+xEnricherGenes <- function(data, background=NULL, check.symbol.identity=F, ontology=NA, ontology.customised=NULL, size.range=c(10,2000), min.overlap=5, which.distance=NULL, test=c("fisher","hypergeo","binomial"), background.annotatable.only=NULL, p.tail=c("one-tail","two-tails"), p.adjust.method=c("BH", "BY", "bonferroni", "holm", "hochberg", "hommel"), ontology.algorithm=c("none","pc","elim","lea"), elim.pvalue=1e-2, lea.depth=2, path.mode=c("all_paths","shortest_paths","all_shortest_paths"), true.path.rule=F, verbose=T, silent=F, RData.location="http://galahad.well.ox.ac.uk/bigdata")
 {
     startT <- Sys.time()
     if(!silent){
@@ -135,25 +136,27 @@ xEnricherGenes <- function(data, background=NULL, check.symbol.identity=F, ontol
     data <- as.character(data)
     
     #################################
- 	aOnto <- xDefineOntology(ontology, verbose=verbose, RData.location=RData.location)
+ 	aOnto <- xDefineOntology(ontology, ontology.customised=ontology.customised, verbose=verbose, RData.location=RData.location)
  	g <- aOnto$g
  	anno <- aOnto$anno
  	if(is.null(g)){
 		warnings("There is no input for the ontology.\n")
         return(NULL)
-	}   
-    #################################
-        
-    ## convert gene symbol to entrz gene for both input data of interest and the input background (if given)
-    if(verbose){
-		now <- Sys.time()
-		message(sprintf("Do gene mapping from Symbols to EntrezIDs (%s) ...", as.character(now)), appendLF=T)
 	}
-    data <- xSymbol2GeneID(data, check.symbol.identity=check.symbol.identity, verbose=verbose, RData.location=RData.location)
-    data <- data[!is.na(data)]
-    if(length(background)>0){
-        background <- xSymbol2GeneID(background, check.symbol.identity=check.symbol.identity, verbose=verbose, RData.location=RData.location)
-        background <- background[!is.na(background)]
+    #################################
+
+    if(is.null(ontology.customised)){
+		## convert gene symbol to entrz gene for both input data of interest and the input background (if given)
+		if(verbose){
+			now <- Sys.time()
+			message(sprintf("Do gene mapping from Symbols to EntrezIDs (%s) ...", as.character(now)), appendLF=T)
+		}
+		data <- xSymbol2GeneID(data, check.symbol.identity=check.symbol.identity, verbose=verbose, RData.location=RData.location)
+		data <- data[!is.na(data)]
+		if(length(background)>0){
+			background <- xSymbol2GeneID(background, check.symbol.identity=check.symbol.identity, verbose=verbose, RData.location=RData.location)
+			background <- background[!is.na(background)]
+		}
     }
     
     #############################################################################################
@@ -167,7 +170,7 @@ xEnricherGenes <- function(data, background=NULL, check.symbol.identity=F, ontol
     eTerm <- xEnricher(data=data, annotation=anno, g=g, background=background, size.range=size.range, min.overlap=min.overlap, which.distance=which.distance, test=test, background.annotatable.only=background.annotatable.only, p.tail=p.tail, p.adjust.method=p.adjust.method, ontology.algorithm=ontology.algorithm, elim.pvalue=elim.pvalue, lea.depth=lea.depth, path.mode=path.mode, true.path.rule=true.path.rule, verbose=verbose)
 	
 	# replace EntrezGenes with gene symbols	
-	if(1 & class(eTerm)=="eTerm"){
+	if(is.null(ontology.customised) & class(eTerm)=="eTerm"){
 		## load Enterz Gene information
 		EG <- xRDataLoader(RData.customised=paste('org.Hs.eg', sep=''), RData.location=RData.location, verbose=verbose)
 		allGeneID <- EG$gene_info$GeneID
@@ -184,6 +187,14 @@ xEnricherGenes <- function(data, background=NULL, check.symbol.identity=F, ontol
 		eTerm$data <- allSymbol[match(eTerm$data,allGeneID)]
 		## background
 		eTerm$background <- allSymbol[match(eTerm$background,allGeneID)]		
+		
+		## annotation
+		annotation <- eTerm$annotation
+		annotation_symbols <- lapply(annotation,function(x){
+			ind <- match(x, allGeneID)
+			allSymbol[ind]
+		})
+		eTerm$annotation <- annotation_symbols
 	}
 	
 	if(verbose){
@@ -199,7 +210,7 @@ xEnricherGenes <- function(data, background=NULL, check.symbol.identity=F, ontol
     
     if(!silent){
     	message(paste(c("\nEnd at ",as.character(endT)), collapse=""), appendLF=TRUE)
-    	message(paste(c("Runtime in total is: ",runTime," secs\n"), collapse=""), appendLF=TRUE)
+    	message(paste(c("Runtime in total (xEnricherGenes): ",runTime," secs\n"), collapse=""), appendLF=TRUE)
     }
     
     invisible(eTerm)
